//
//  VPNUAccountUserInfo.h
//  VPNUnlimitedSDK
//
//  Copyright (c) 2015 KeepSolid. All rights reserved.
//

//
// Use of this SDK is subject to the VPN Unlimited SDK License Agreement
// https://www.keepsolid.com/static/docs/VPN_Unlimited_SDK_License.html
//

#import <Foundation/Foundation.h>

/*!
 @class VPNUAccountInfo
 @abstract
 A model object which describes user's account information.
 */

NS_AVAILABLE(10_7, 7_0)
@interface VPNUAccountUserInfo : NSObject

/*!
 @brief A boolean value which indicates if account needs a confirmation.
 */
@property (assign, readonly) BOOL needsConfirmation NS_AVAILABLE(10_7, 7_0);
/*!
 @brief A boolean value which indicates if account is confirmed.
 */
@property (assign, readonly, getter=isConfirmed) BOOL confirmed NS_AVAILABLE(10_7, 7_0);
/*!
 @brief A boolean value which indicates if current login is the first one.
 */
@property (assign, readonly, getter=isFirstLogin) BOOL firstLogin NS_AVAILABLE(10_7, 7_0);
/*!
 @brief A boolean value which indicates if invites for account are available.
 */
@property (assign, readonly) BOOL invitesAvailable NS_AVAILABLE(10_7, 7_0);
/*!
 @brief User's account ID (usually an email).
 */
@property (nonatomic, readonly) NSString *username NS_AVAILABLE(10_7, 7_0);
/*!
 @brief User's name.
 */
@property (nonatomic, readonly) NSString *name NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Autologin URL.
 */
@property (nonatomic, readonly) NSString *autologinURI NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Initializes and returns a newly allocated account info object with the specified dictionary object.
 @param dictionary The dictionary object for internal usage.
 @return An initialized account info object or nil if the object couldn't be created.
 */
- (VPNUAccountUserInfo *)initWithDictionary:(NSDictionary *)dictionary NS_AVAILABLE(10_7, 7_0) NS_DESIGNATED_INITIALIZER;

@end

