//
//  VPNUServerItem.h
//  VPNUnlimitedSDK
//
//  Copyright (c) 2015 KeepSolid. All rights reserved.
//

//
// Use of this SDK is subject to the VPN Unlimited SDK License Agreement
// https://www.keepsolid.com/static/docs/VPN_Unlimited_SDK_License.html
//

#import <Foundation/Foundation.h>

/*!
 @class VPNUServerItem
 @abstract
 A model object which describes a VPN server.
 */
NS_AVAILABLE(10_7, 7_0)
@interface VPNUServerItem : NSObject <NSCoding>
/*!
 @brief Server's name.
 */
@property (nonatomic, readonly) NSString *name NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Server's description.
 */
@property (nonatomic, readonly) NSString *shortDescription NS_AVAILABLE(10_7, 7_0);
/*!
 @brief A concatenation of @c name and @c shortDescription properties.
 */
@property (nonatomic, readonly) NSString *fullDescription NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Domain which represents the server.
 */
@property (nonatomic, readonly) NSString *domain NS_AVAILABLE(10_7, 7_0);
/*!
 @brief The region shorthand description.
 */
@property (nonatomic, readonly) NSString *region NS_AVAILABLE(10_7, 7_0);
/*!
 @brief URI of region country's flag image.
 */
@property (nonatomic, readonly) NSString *flagURI NS_AVAILABLE(10_7, 7_0);
/*!
 @brief URI of region country's flat flag image.
 */
@property (nonatomic, readonly) NSString *flatFlagURI NS_AVAILABLE(10_7, 7_0);
/*!
 @brief URI of region country's small flat flag image.
 */
@property (nonatomic, readonly) NSString *smallFlatFlagURI NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Region's latitude.
 */
@property (nonatomic, readonly) double latitude NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Region's longitude.
 */
@property (nonatomic, readonly) double longitude NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Server's priority.
 */
@property (nonatomic, readonly) NSInteger priority NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Server's network load.
 */
@property (nonatomic, readonly) double networkLoad NS_AVAILABLE(10_7, 7_0);
/*!
 @brief Server is restricted from P2P usage.
 */
@property (nonatomic, readonly, getter=isP2PRestricted) BOOL P2PRestricted NS_AVAILABLE(10_7, 7_0);

@end
